@@ -8,7 +8,7 @@ def read_varlen(data):
             # no next BYTE
             NEXTBYTE = 0
         # mask out the 8th bit
-        chr = chr & 0x7f
+        chr = chr & 0x7F
         # shift last value up 7 bits
         value = value << 7
         # add new value
